<?php declare(strict_types=1);

namespace Infomaker\Everyware\NewsML;

use Infomaker\Everyware\Support\Arr;
use Infomaker\Everyware\Support\GenericPropertyObject;
use Infomaker\Everyware\Support\Interfaces\PropertyObject;
use SimpleXMLIterator;
use SimpleXMLElement;

class Item extends GenericPropertyObject implements PropertyObject
{

    /**
     * @var SimpleXMLIterator
     */
    protected $el;

    public function __construct(SimpleXMLIterator $el)
    {
        $this->fill(Arr::get((array)$el->attributes(), '@attributes', []));
        $this->el = $el;
    }

    /**
     * Filter the content of the blocks from unwanted elements.
     * This function will be applied to every block
     *
     * @param string $text
     * @param array $allowedTags
     *
     * @return string
     * @since 0.1
     */
    public function filterInlineContent(string $text = '', array $allowedTags = []): string
    {
        if (!empty($allowedTags)) {
            return trim(strip_tags($text, '<' . implode('><', $allowedTags) . '>'));
        }

        return $text;
    }

    public function getItemAttributes(): array
    {
        return $this->getProperties();
    }

    public function getItemAttribute(string $key = '', $default = '')
    {
        $itemAttributes = $this->getItemAttributes();
        if (array_key_exists($key, $itemAttributes)) {
            return $itemAttributes[$key];
        }

        return $default;
    }

    public function getType(): string
    {
        return Arr::get($this->getItemAttributes(), 'type', '');
    }

    public function getChild(string $name): ?SimpleXMLIterator
    {
        if(!isset($this->el->$name )){
            print_r('<pre>');
            //look for me
            var_dump( $name );
            print_r('</pre>');
        }

        return $this->el->$name ?? null;
    }

    public function removeLinebreak(string $xml): string
    {
        return implode('', array_map('trim', explode(PHP_EOL, $xml)));
    }

    public function getContentAsXML(): string
    {
        return $this->removeLinebreak($this->el->asXML());
    }

    public function getFilteredContent(array $allowedTags = []): string
    {
        return $this->filterInlineContent($this->getContentAsXML(), $allowedTags);
    }
}
