<?php declare(strict_types=1);

namespace Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\Support\Arr;
use SimpleXMLIterator;

/**
 * GroupParser
 *
 * @link    http://infomaker.se
 * @package Infomaker\Everyware\NewsML\Parsers
 * @since   Infomaker\Everyware\NewsML\Parsers\GroupParser 1.0.0
 */
class GroupParser implements ItemParser
{

    public const TAG = 'group';

    /**
     * @var ItemParser[]
     */
    private $parsers;

    public function __construct(ElementParser $elementParser, ObjectParser $objectParser)
    {
        $this->parsers = [
            ElementParser::TAG => $elementParser,
            ObjectParser::TAG => $objectParser,
            self::TAG => $this
        ];
    }

    public function parse(SimpleXMLIterator $element): array
    {
        $items = [];
        foreach ($element as $tag => $item) {
            $parser = Arr::get($this->parsers, $tag, null);

            if ($parser instanceof ItemParser) {
                $items[] = $parser->parse($item);
            }
        }

        return Arr::flatten($items, 1);
    }
}
