<?php declare(strict_types=1);

namespace Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\Support\Arr;
use Infomaker\Everyware\NewsML\Item;
use Infomaker\Everyware\NewsML\TypeParser;
use SimpleXMLIterator;

class LinkObjectParser implements ItemParser, TypeParser
{

    public const OBJECT_TYPE = 'x-im/link';

    /**
     * @var LinkParser
     */
    protected $linkParser;

    public function __construct()
    {
        $this->linkParser = new LinkParser();
    }

    public function parse(SimpleXMLIterator $element): array
    {

        $item = new Item($element);
        $item->fill($this->getLinkAttributes($element));

        return [$item];
    }

    private function getLinkAttributes(SimpleXMLIterator $element): array
    {
        $links = $this->linkParser->parseLinks($element);
        if (!empty($links)) {
            foreach ($links as $index => $link) {
                if ($link instanceof Item) {
                    $attributes = $link->getItemAttributes();
                    if (Arr::get($attributes, 'rel', '') === 'self') {
                        return $attributes;
                    }
                }
            }
        }

        return [];
    }

    public function typeToParse(): string
    {
        return static::OBJECT_TYPE;
    }
}
