<?php declare(strict_types=1);

namespace Infomaker\Everyware\NewsML\Parsers;

use Infomaker\Everyware\NewsML\Objects\TeaserItem;
use Infomaker\Everyware\NewsML\TypeParser;
use SimpleXMLIterator;

class TeaserParser implements ItemParser, TypeParser
{

    public const OBJECT_TYPE = 'x-im/teaser';

    /**
     * @var LinkParser
     */
    protected $linkParser;

    public function __construct()
    {
        $this->linkParser = new LinkParser([
            ImageLinkParser::LINK_TYPE => new ImageLinkParser()
        ]);
    }

    public function parse(SimpleXMLIterator $element): array
    {
        $item = new TeaserItem($element);
        $item->fill(array_replace($this->getData($element->data), [
            'type' => $item->getType(),
            'links' => $this->linkParser->parseLinks($element)
        ]));

        return [$item];
    }

    protected function getData($data = null)
    {
        $defaultData = [
            'headline' => '',
            'text' => '',
            'subject' => ''
        ];

        if ($data === null) {
            return $defaultData;
        }

        return array_replace($defaultData, array_filter([
            'headline' => (string)$data->title,
            'text' => (string)$data->text,
            'subject' => (string)$data->subject
        ]));
    }

    public function typeToParse(): string
    {
        return static::OBJECT_TYPE;
    }
}
